==> sflphone_1.0.1.orig.tar.gz: sflphone-1.0.1/daemon/src/call.cpp <==
/*
 *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
 *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
 *  Author : Laurielle Lea <laurielle.lea@savoirfairelinux.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Additional permission under GNU GPL version 3 section 7:
 *
 *  If you modify this program, or any covered work, by linking or
 *  combining it with the OpenSSL project's OpenSSL library (or a
 *  modified version of that library), containing parts covered by the
 *  terms of the OpenSSL or SSLeay licenses, Savoir-Faire Linux Inc.
 *  grants you additional permission to convey the resulting work.
 *  Corresponding Source for a non-source form of such a combination
 *  shall include the source code for the parts of OpenSSL used as well
 *  as that of the covered work.
 */
#include "call.h"
#include "manager.h"
#include "audio/mainbuffer.h"

const char * const Call::DEFAULT_ID = "audiolayer_id";

Call::Call(const std::string& id, Call::CallType type)
    : callMutex_()
    , localIPAddress_("")
    , localAudioPort_(0)
    , id_(id)
    , confID_()
    , type_(type)
    , connectionState_(Call::Disconnected)
    , callState_(Call::Inactive)
    , callConfig_(Call::Classic)
    , peerName_()
    , peerNumber_()
    , displayName_()
{}

Call::~Call()
{}

void
Call::setConnectionState(ConnectionState state)
{
    ost::MutexLock m(callMutex_);
    connectionState_ = state;
}

Call::ConnectionState
Call::getConnectionState()
{
    ost::MutexLock m(callMutex_);
    return connectionState_;
}


void
Call::setState(CallState state)
{
    ost::MutexLock m(callMutex_);
    callState_ = state;
}

Call::CallState
Call::getState()
{
    ost::MutexLock m(callMutex_);
    return callState_;
}

std::string
Call::getStateStr()
{
    switch (getState()) {
        case Active:
            switch (getConnectionState()) {
                case Ringing:
                    return isIncoming() ? "INCOMING" : "RINGING";
                case Connected:
                default:
                    return isRecording() ? "RECORD" : "CURRENT";
            }

        case Hold:
            return "HOLD";
        case Busy:
            return "BUSY";
        case Inactive:

            switch (getConnectionState()) {
                case Ringing:
                    return isIncoming() ? "INCOMING" : "RINGING";
                case Connected:
                    return "CURRENT";
                default:
                    return "INACTIVE";
            }

        case Conferencing:
            return "CONFERENCING";
        case Refused:
        case Error:
        default:
            return "FAILURE";
    }
}


std::string
Call::getLocalIp()
{
    ost::MutexLock m(callMutex_);
    return localIPAddress_;
}

unsigned int
Call::getLocalAudioPort()
{
    ost::MutexLock m(callMutex_);
    return localAudioPort_;
}

bool
Call::setRecording()
{
    bool recordStatus = Recordable::recAudio.isRecording();

    Recordable::recAudio.setRecording();
    MainBuffer *mbuffer = Manager::instance().getMainBuffer();
    std::string process_id = Recordable::recorder.getRecorderID();

    if (!recordStatus) {
        mbuffer->bindHalfDuplexOut(process_id, id_);
        mbuffer->bindHalfDuplexOut(process_id);

        Recordable::recorder.start();
    } else {
        mbuffer->unBindHalfDuplexOut(process_id, id_);
        mbuffer->unBindHalfDuplexOut(process_id);
    }

    Manager::instance().getMainBuffer()->stateInfo();

    return recordStatus;
}

==> sflphone_1.1.0.orig.tar.gz: sflphone-1.1.0/daemon/src/call.cpp <==
/*
 *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
 *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
 *  Author : Laurielle Lea <laurielle.lea@savoirfairelinux.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Additional permission under GNU GPL version 3 section 7:
 *
 *  If you modify this program, or any covered work, by linking or
 *  combining it with the OpenSSL project's OpenSSL library (or a
 *  modified version of that library), containing parts covered by the
 *  terms of the OpenSSL or SSLeay licenses, Savoir-Faire Linux Inc.
 *  grants you additional permission to convey the resulting work.
 *  Corresponding Source for a non-source form of such a combination
 *  shall include the source code for the parts of OpenSSL used as well
 *  as that of the covered work.
 */
#include "call.h"
#include "manager.h"
#include "audio/mainbuffer.h"
#include "history/historyitem.h"

Call::Call(const std::string& id, Call::CallType type)
    : callMutex_()
    , localIPAddress_("")
    , localAudioPort_(0)
    , id_(id)
    , confID_()
    , type_(type)
    , connectionState_(Call::DISCONNECTED)
    , callState_(Call::INACTIVE)
    , isIPToIP_(false)
    , peerNumber_()
    , displayName_()
    , timestamp_start_(0)
    , timestamp_stop_(0)
{
    time(&timestamp_start_);
}

Call::~Call()
{}

void
Call::setConnectionState(ConnectionState state)
{
    ost::MutexLock m(callMutex_);
    connectionState_ = state;
}

Call::ConnectionState
Call::getConnectionState()
{
    ost::MutexLock m(callMutex_);
    return connectionState_;
}

void
Call::setState(CallState state)
{
    ost::MutexLock m(callMutex_);
    callState_ = state;
}

Call::CallState
Call::getState()
{
    ost::MutexLock m(callMutex_);
    return callState_;
}

std::string
Call::getStateStr()
{
    switch (getState()) {
        case ACTIVE:
            switch (getConnectionState()) {
                case RINGING:
                    return isIncoming() ? "INCOMING" : "RINGING";
                case CONNECTED:
                default:
                    return isRecording() ? "RECORD" : "CURRENT";
            }

        case HOLD:
            return "HOLD";
        case BUSY:
            return "BUSY";
        case INACTIVE:

            switch (getConnectionState()) {
                case RINGING:
                    return isIncoming() ? "INCOMING" : "RINGING";
                case CONNECTED:
                    return "CURRENT";
                default:
                    return "INACTIVE";
            }

        case CONFERENCING:
            return "CONFERENCING";
        case REFUSED:
        case ERROR:
        default:
            return "FAILURE";
    }
}


std::string
Call::getLocalIp()
{
    ost::MutexLock m(callMutex_);
    return localIPAddress_;
}

unsigned int
Call::getLocalAudioPort()
{
    ost::MutexLock m(callMutex_);
    return localAudioPort_;
}

bool
Call::setRecording()
{
    bool recordStatus = Recordable::recAudio_.isRecording();

    Recordable::recAudio_.setRecording();
    MainBuffer *mbuffer = Manager::instance().getMainBuffer();
    std::string process_id = Recordable::recorder_.getRecorderID();

    if (!recordStatus) {
        mbuffer->bindHalfDuplexOut(process_id, id_);
        mbuffer->bindHalfDuplexOut(process_id, MainBuffer::DEFAULT_ID);

        Recordable::recorder_.start();
    } else {
        mbuffer->unBindHalfDuplexOut(process_id, id_);
        mbuffer->unBindHalfDuplexOut(process_id, MainBuffer::DEFAULT_ID);
    }

    Manager::instance().getMainBuffer()->stateInfo();

    return recordStatus;
}

void Call::time_stop()
{
    time(&timestamp_stop_);
}

std::string Call::getTypeStr() const
{
    switch (type_) {
        case INCOMING:
            return "incoming";
        case OUTGOING:
            return "outgoing";
        case MISSED:
            return "missed";
        default:
            return "";
    }
}

std::map<std::string, std::string> Call::createHistoryEntry() const
{
    std::map<std::string, std::string> result;
    result[HistoryItem::ACCOUNT_ID_KEY] = Manager::instance().getAccountFromCall(id_);
    result[HistoryItem::CONFID_KEY] = confID_;
    result[HistoryItem::CALLID_KEY] = id_;
    result[HistoryItem::DISPLAY_NAME_KEY] = displayName_;
    result[HistoryItem::PEER_NUMBER_KEY] = peerNumber_;
    result[HistoryItem::RECORDING_PATH_KEY] = recAudio_.fileExists() ? getFilename() : "";
    std::stringstream time_str;
    time_str << timestamp_start_;
    result[HistoryItem::TIMESTAMP_START_KEY] = time_str.str();
    time_str.str("");
    time_str << timestamp_stop_;
    result[HistoryItem::TIMESTAMP_STOP_KEY] = time_str.str();
    if (connectionState_ == RINGING)
        result[HistoryItem::STATE_KEY] = HistoryItem::MISSED_STRING;
    else
        result[HistoryItem::STATE_KEY] = getTypeStr();
    return result;
}
